/**
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 */

const { EventEmitter } = require('node:events')
const { log } = require('codeceptjs').output

const dispatcher = new EventEmitter()

module.exports = {
  dispatcher,
  provisioning: {
    user: {
      create: 'provisioning.user.create',
      created: 'provisioning.user.created',
      removed: 'provisioning.user.removed'

    },
    context: {
      create: 'provisioning.context.create',
      created: 'provisioning.context.created',
      removed: 'provisioning.context.removed'
    }
  },
  emit (event, param) {
    let msg = `Emitted | ${event}`
    if (param && param.toString()) {
      msg += ` (${param.toString()})`
    }
    log(msg)
    try {
      this.dispatcher.emit.apply(this.dispatcher, arguments)
    } catch (err) {
      log(`Error processing ${event} event:`)
      log(err.stack)
    }
  }
}
