import { describe, it, expect, afterEach } from '@jest/globals'
import vitePluginProxy from '../../dist/index'
import { closeAllServers, createTestServer, createViteServer, getPort, getDirname, http2Request, updateRequestManager } from '../util'

const PORT = getPort()
const PROXY_PORT = getPort()
const SERVER_PORT = getPort()
const __dirname = getDirname(import.meta.url)

describe('http proxy', function () {
  afterEach(async function () {
    await closeAllServers()
    updateRequestManager()
  })

  it.skip('works', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        proxy: {
          '/api': {
            target: `http://localhost:${SERVER_PORT}`
          }
        },
        httpProxy: {
          target: 'http://localhost',
          port: PROXY_PORT
        }
      })]
    }, PORT)

    const server = createTestServer()
    server.get('/api/test', (req, res) => {
      res.send({ hello: 'world' })
    })
    await server.listen({ port: SERVER_PORT })

    const { data } = await http2Request(`http://localhost:${PORT}/api/test`)
    expect(data).toEqual({ hello: 'world' })

    const { data: proxiedData } = await http2Request(`http://localhost:${PROXY_PORT}/api/test`)
    expect(proxiedData).toEqual({ hello: 'world' })
  })
})
